@@ -42,7 +42,7 @@
 #' \code{radiusCalculation = JS("Math.sqrt(d.nodesize)+6")}.
 #' @param charge numeric value indicating either the strength of the node
 #' repulsion (negative value) or attraction (positive value).
-#' @param linkColour character string specifying the colour you want the link
+#' @param linkColour character vector specifying the colour(s) you want the link
 #' lines to be. Multiple formats supported (e.g. hexadecimal).
 #' @param opacity numeric value of the proportion opaque you would like the
 #' graph elements to be.
@@ -58,7 +58,6 @@
 #' when a node is clicked.
 #'
 #' @examples
-#' #### Tabular data example.
 #' # Load data
 #' data(MisLinks)
 #' data(MisNodes)
@@ -80,7 +79,7 @@
 #' # Create URL. paste0 used purely to keep within line width.
 #' URL <- paste0("https://cdn.rawgit.com/christophergandrud/networkD3/",
 #'               "master/JSONdata/miserables.json")
-#' 
+#'
 #' MisJson <- jsonlite::fromJSON(URL)
 #'
 #' # Create graph
@@ -105,17 +104,31 @@
 #'              Group = "group", opacity = 0.4, bounded = TRUE,
 #'              opacityNoHover = TRUE)
 #'
+#' ## Specify colours for specific edges
+#' # Find links to Valjean (11)
+#' which(MisNodes == "Valjean", arr = TRUE)[1] - 1
+#' ValjeanInds = which(MisLinks == 11, arr = TRUE)[, 1]
 #'
-#' # Create graph with alert pop-up when a node is clicked.  You're
+#' # Create a colour vector
+#' ValjeanCols = ifelse(1:nrow(MisLinks) %in% ValjeanInds, "#bf3eff", "#666")
+#'
+#' forceNetwork(Links = MisLinks, Nodes = MisNodes, Source = "source",
+#'              Target = "target", Value = "value", NodeID = "name",
+#'              Group = "group", opacity = 0.8, linkColour = ValjeanCols)
+#'
+#'
+#' ## Create graph with alert pop-up when a node is clicked.  You're
 #' # unlikely to want to do exactly this, but you might use
 #' # Shiny.onInputChange() to allocate d.XXX to an element of input
 #' # for use in a Shiny app.
+#'
 #' MyClickScript <- 'alert("You clicked " + d.name + " which is in row " +
 #'        (d.index + 1) +  " of your original R data frame");'
+#'
 #' forceNetwork(Links = MisLinks, Nodes = MisNodes, Source = "source",
 #'              Target = "target", Value = "value", NodeID = "name",
-#'              Group = "group", opacity = 1, zoom = F, bounded = T,
-#'              clickAction = MyClickScript)
+#'              Group = "group", opacity = 1, zoom = FALSE,
+#'              bounded = TRUE, clickAction = MyClickScript)
 #' }
 #'
 
@@ -180,6 +193,8 @@ forceNetwork <- function(Links,
                 names(NodesDF) <- c("name", "group")
                 nodesize = FALSE
         }
+        LinksDF <- data.frame(LinksDF, colour=linkColour)
+        LinksDF$colour = as.character(LinksDF$colour)
 
         # create options
         options = list(
@@ -192,7 +207,7 @@ forceNetwork <- function(Links,
                 linkDistance = linkDistance,
                 linkWidth = linkWidth,
                 charge = charge,
-                linkColour = linkColour,
+                # linkColour = linkColour,
                 opacity = opacity,
                 zoom = zoom,
                 legend = legend,
